@@ -214,9 +214,18 @@ def isAcLive(): ...
 def restart(): ...
 
 
+# same as ac.isCarInPitline()
 def isCarInPitlane(): ...
 
 
+# same as ac.isCarInPitlane()
+def isCarInPitline(): ...
+
+
+# noticed in the SimHub mod
+def isCarInPit(): ...
+
+
 def getCarSkin(car_id): ...
 
 
@@ -269,3 +278,18 @@ def sendChatMessage(string_msg): ...
 
 
 def addOnChatMessageListener(ac_window_id, call_back_function): ...
+
+
+def getFocusedCar() -> int: ...
+
+
+def getCarsCount(): ...
+
+
+def getCarLeaderboardPosition(car_id): ...
+
+
+def getCarRealTimeLeaderboardPosition(car_id): ...
+
+
+def isConnected(car_id): ...
